From b7e5e13ed25252f4f92d1cf2fa7d70f14f64bb43 Mon Sep 17 00:00:00 2001
From: Niels Thykier <niels@thykier.net>
Date: Fri, 6 Apr 2018 20:07:57 +0000
Subject: [PATCH 2/2] cmake: Support ninja backend

Signed-off-by: Niels Thykier <niels@thykier.net>
---
 lib/Debian/Debhelper/Buildsystem/cmake.pm | 12 +++++++++++-
 lib/Debian/Debhelper/Dh_Buildsystems.pm   |  1 +
 t/buildsystems/03-bs-auto-buildable.t     |  2 +-
 3 files changed, 13 insertions(+), 2 deletions(-)

diff --git a/lib/Debian/Debhelper/Buildsystem/cmake.pm b/lib/Debian/Debhelper/Buildsystem/cmake.pm
index a342e436..d9436bae 100644
--- a/lib/Debian/Debhelper/Buildsystem/cmake.pm
+++ b/lib/Debian/Debhelper/Buildsystem/cmake.pm
@@ -27,6 +27,11 @@ my %DEB_HOST2CMAKE_SYSTEM = (
 	'hurd'     => 'GNU',
 );
 
+my %TARGET_BUILD_SYSTEM2CMAKE_GENERATOR = (
+	'makefile' => 'Unix Makefiles',
+	'ninja'    => 'Ninja',
+);
+
 sub DESCRIPTION {
 	"CMake (CMakeLists.txt)"
 }
@@ -36,7 +41,7 @@ sub IS_GENERATOR_BUILD_SYSTEM {
 }
 
 sub SUPPORTED_TARGET_BUILD_SYSTEMS {
-	return qw(makefile);
+	return qw(makefile ninja);
 }
 
 sub check_auto_buildable {
@@ -71,10 +76,15 @@ sub configure {
 	my $this=shift;
 	# Standard set of cmake flags
 	my @flags = @STANDARD_CMAKE_FLAGS;
+	my $backend = $this->{targetbuildsystem}->NAME;
 
 	if (not compat(10)) {
 		push(@flags, '-DCMAKE_INSTALL_RUNSTATEDIR=/run');
 	}
+	if (exists($TARGET_BUILD_SYSTEM2CMAKE_GENERATOR{$backend})) {
+		my $generator = $TARGET_BUILD_SYSTEM2CMAKE_GENERATOR{$backend};
+		push(@flags, "-G${generator}");
+	}
 
 	if (is_cross_compiling()) {
 		my $deb_host = dpkg_architecture_value("DEB_HOST_ARCH_OS");
diff --git a/lib/Debian/Debhelper/Dh_Buildsystems.pm b/lib/Debian/Debhelper/Dh_Buildsystems.pm
index 7f3a96b4..96c1e57b 100644
--- a/lib/Debian/Debhelper/Dh_Buildsystems.pm
+++ b/lib/Debian/Debhelper/Dh_Buildsystems.pm
@@ -26,6 +26,7 @@ our @BUILDSYSTEMS = (
 	"python_distutils",
 	(compat(7) ? "perl_build" : ()),
 	"cmake+makefile",
+	"cmake+ninja",
 	"ant",
 	"qmake",
 	"qmake_qt4",
diff --git a/t/buildsystems/03-bs-auto-buildable.t b/t/buildsystems/03-bs-auto-buildable.t
index 082e38bf..df4405b2 100755
--- a/t/buildsystems/03-bs-auto-buildable.t
+++ b/t/buildsystems/03-bs-auto-buildable.t
@@ -2,7 +2,7 @@
 
 use strict;
 use warnings;
-use Test::More tests => 182;
+use Test::More tests => 187;
 
 use File::Temp qw(tempdir);
 use File::Basename qw(dirname);
-- 
2.16.3

